@@ -19,7 +19,7 @@ with 'Data::Object::Role::Stashable';
 
 use DBI;
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 # ATTRIBUTES
 
@@ -155,7 +155,7 @@ method dsngen(Str $name) {
 
 =head1 NAME
 
-Test::DB::Mysql
+Test::DB::Mysql - Temporary Testing Databases for Mysql
 
 =cut
 
