@@ -22,7 +22,7 @@ use File::Copy ();
 use File::Spec ();
 use File::Temp ();
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 # ATTRIBUTES
 
@@ -86,7 +86,7 @@ method destroy() {
 
 =head1 NAME
 
-Test::DB::Sqlite
+Test::DB::Sqlite - Temporary Testing Databases for Sqlite
 
 =cut
 
